strtoimax

Function strtoimax 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn strtoimax( nptr: *const c_char, endptr: *mut *mut c_char, base: c_int, ) -> intmax_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/strtoimax.html.

Equivalent to strtol() and strtoll(), except that the initial portion of the string shall be converted to intmax_t.

Upon success, returns the converted value. If no conversion could be performed or the value of base is not supported, returns 0.